# Qmlview-wheel
The wheel distribution repo for Qmlview

Qmlview is a command line utility. But sort of to replace the non-existent qmlscene, which was used to preview qml source code before it is loaded by any C++, Java, or python code.




## Change Log

### V2.1
* Supports QtCharts
* Works with PyQt5.15
* Bug fixes
* * Delete resource file on app close
